#
# set version information
#
setversion()
{
  major="9"
  minor="4"
  release="1"
  version="${major}.${minor}"
  ver="${major}${minor}"
  fullver="${major}.${minor}.${release}"
}
#
# set platform
#
setplatform ()
{
  platform=`cat ${1}/setup/platform.txt`
}
#
# uninstall all installed products
#
uninstallproducts ()
{
  cd $1
  if [  -f setup/uninstRCD.sh ]; then
    ./setup/uninstRCD.sh
  fi
  if [  -f setup/uninstRWD.sh ]; then
    ./setup/uninstRWD.sh
  fi
  if [  -f setup/uninstRDS.sh ]; then
    ./setup/uninstRDS.sh
  fi
  if [  -f setup/uninstRTD.sh ]; then
    ./setup/uninstRTD.sh
  fi
  rm setup/reclib.sh 				> /dev/null 2>&1
  if [  -d setup ]; then
    rm setup
  fi
  cd ../
  if [  -d recital ]; then
    rm recital
  fi
  if [  -d /usr/recital ]; then
    rm /usr/recital
  fi
}
#
# Remove files used for the installation
#
removeinstallfiles ()
{
  cd $1
echo "2=${2}" > /tmp/removeinstallfiles.lis
  for file in `ls ${2}-*.tar`
  do
    rm $file > /dev/null 2>&1
  done
  for file in `ls setup/${2}.rpm`
  do
    rm $file > /dev/null 2>&1
  done
}
#
# extract the files
#
extractfile ()
{
  if [ "${linux}" = "1" ]; then
    gunzip -f ./${2}${platform}.tar.gz 2> /dev/null
  else
    uncompress ./${2}${platform}.tar.Z 2> /dev/null
  fi
  file=`ls ${2}*.tar`
  tarloc=`pwd`
  if [ ! "$1" = "" ];then
    cd $1
  fi
  tar xvf ${tarloc}/${2}${platform}.tar > /dev/null
}
#
# Setup Recital global environment file
#
globalenv ()
{
  echo "#!/bin/sh" 								>  /tmp/$$
  if [ "$1" = "" ];then
    ROI_ROOT=`pwd`/
  else
    ROI_ROOT=$1/
  fi
  echo "ROI_ROOT=${ROI_ROOT} ; export ROI_ROOT"	>> /tmp/$$
  setplatform ${ROI_ROOT}
  if [ "" = "$platform" ];then
    echo "Installation platform not found."
    echo "Operation cancelled."
    exit -1
  fi
  echo "ROI_MACHINE=$platform ; export ROI_MACHINE"	>> /tmp/$$
  chmod +x  /tmp/$$ 
  mv  /tmp/$$ /usr/bin/recital${ver}${2}.sh
}
#
# Add to rpm
#
addrpm()
{
  rpm -i setup/${1}-${fullver}.rpm
}
#
# Delete from rpm
#
delrpm()
{
  rpm -e ${1}-${version}-${release}
}
#
# Add a menu shortcut
#
addmenu()
{
  #
  # Create shortcut for Gnome
  #
  if [ -d /usr/share/applications ];then
    if [ -f ${HOME}/Desktop/Recital.desktop ];then
      cp ${HOME}/Desktop/Recital.desktop /usr/share/applications/Recital.desktop
    fi
    if [ -f ${HOME}/.gnome-desktop/Recital.desktop ];then
      cp ${HOME}/.gnome-desktop/Recital.desktop /usr/share/applications/Recital.desktop
    fi
  fi 
  #
  # Create shortcut for KDE
  #
  if [ -f ${HOME}/Desktop/Recital.kdelnk ];then
    if [ -d /usr/share/applnk/ ];then
      if [ ! -d /usr/share/applnk/Programming ];then
        mkdir /usr/share/applnk/Programming
      fi
      cp ${HOME}/Desktop/Recital.kdelnk /usr/share/applnk/Programming/Recital.kdelnk
    fi
    if [ -d /usr/share/applnk-redhat/ ];then
      if [ ! -d /usr/share/applnk-redhat/Programming ];then
        mkdir /usr/share/applnk-redhat/Programming
      fi
      cp ${HOME}/Desktop/Recital.kdelnk /usr/share/applnk-redhat/Programming/Recital.kdelnk
    fi
  fi
 
}
#
# Delete desktop shortcuts
#
delmenu()
{
  if [ -f /usr/share/applications/Recital.desktop ];then
    rm /usr/share/applications/Recital.desktop
  fi
  if [ -f /usr/share/applnk/Programming/Recital.kdelnk ];then
    rm /usr/share/applnk/Programming/Recital.kdelnk
  fi
  if [ -f /usr/share/applnk-redhat/Programming/Recital.kdelnk ];then
    rm /usr/share/applnk-redhat/Programming/Recital.kdelnk
  fi
}
#
# Delete a desktop shortcut
#
addshortcut()
{
  #
  # Create shortcut for Gnome
  #
  echo "[Desktop Entry]" 			>  /tmp/$$
  echo "Type=Application"	 		>> /tmp/$$
  echo "Version=1.0"		 	>> /tmp/$$
  echo "Name=Recital"		 		>> /tmp/$$
  echo "Comment=Recital Terminal Developer"	>> /tmp/$$
  echo "Icon=${1}/images/db32.png"		>> /tmp/$$
  echo "Exec=db"				>> /tmp/$$
  echo "Path=${HOME}"					>> /tmp/$$
  echo "Terminal=false"				>> /tmp/$$
  echo "Categories=GTK;GNOME;Development;"	>> /tmp/$$
  if [ -d $HOME/.gnome-desktop ];then
     cp /tmp/$$ ${HOME}/.gnome-desktop/Recital.desktop 
     gnomeshortcut=${HOME}/.gnome-desktop/Recital.desktop
     gnomepath=.gnome-desktop
  fi
  if [ -d $HOME/Desktop ];then
     cp /tmp/$$ ${HOME}/Desktop/Recital.desktop 
     gnomeshortcut=${HOME}/Desktop/Recital.desktop
     gnomepath=Desktop
  fi
  if [ -d /opt/kde3/share/applnk ];then
    cp /tmp/$$ /opt/kde3/share/applnk/Recital.desktop
     gnomeshortcut=/opt/kde3/share/applnk/Recital.desktop
  fi
  #
  # Create shortcut for KDE
  #
  echo "# KDE Config File"				>  /tmp/$$
  echo "[KDE Desktop Entry]"				>> /tmp/$$
  echo "Comment[C]=Run Recital Terminal Developer"	>> /tmp/$$
  echo "SwallowTitle="					>> /tmp/$$
  echo "SwallowExec="					>> /tmp/$$
  echo "BinaryPattern="					>> /tmp/$$
  echo "MimeType="					>> /tmp/$$
  echo "Exec=db"					>> /tmp/$$
  echo "Icon=${1}/images/db32.xpm"			>> /tmp/$$
  echo "TerminalOptions="				>> /tmp/$$
  echo "Type=Application"				>> /tmp/$$
  echo "Terminal=0"					>> /tmp/$$
  echo "Name=Recital Terminal Developer"		>> /tmp/$$
  if [ -d $HOME/Desktop ];then
     if [ ! -f ${HOME}/Desktop/Recital.desktop ];then
		 cp /tmp/$$ ${HOME}/Desktop/Recital.desktop 
     fi
     kdeshortcut=${HOME}/Desktop/Recital.kdelnk
     kdepath=Desktop
  fi
  #
  # add shortcut for all existing users
  #
  if [ "$2" == "AnyOne" ];then
    for i in `cat /etc/passwd | cut -f6,7 -d:`
    do
      var1=`echo $i | grep -v nologin | grep -v shutdown | grep -v sync | grep -v halt`
      if [ "$var1" != "" ];then
        var2=`echo $var1 | cut -f2 -d:`
        if [ "$var2" != "" ];then
          homepath=`echo $var1 | cut -f1 -d:`
          if [ "${gnomeshortcut}" != "" ];then
            if [ ! -d ${homepath}/${gnomepath} ];then
              mkdir ${homepath}/${gnomepath}
            fi
            cp ${gnomeshortcut} $homepath/${gnomepath}/
          fi
          if [ "${kdeshortcut}" != "" ];then
            if [ ! -d ${homepath}/${kdepath} ];then
              mkdir ${homepath}/${kdepath}
            fi
            cp ${kdeshortcut} $homepath/${kdepath}/
          fi
        fi 
      fi
    done
  fi
}
#
# Delete desktop shortcuts
#
delshortcut()
{
  for i in `cat /etc/passwd | cut -f6,7 -d:`
  do
    var1=`echo $i | grep -v nologin | grep -v shutdown | grep -v sync | grep -v halt`
    if [ "$var1" != "" ];then
      var2=`echo $var1 | cut -f2 -d:`
      if [ "$var2" != "" ];then
        homepath=`echo $var1 | cut -f1 -d:`
        if [ -f ${homepath}/Desktop/Recital.desktop ];then
          rm ${homepath}/Desktop/Recital.desktop
        fi
        if [ -f ${homepath}/.gnome-desktop/Recital.desktop ];then
          rm ${homepath}/.gnome-desktop/Recital.desktop
        fi
        if [ -f ${homepath}/Desktop/Recital.kdelnk ];then
          rm ${homepath}/Desktop/Recital.kdelnk
        fi
      fi 
    fi
  done
}
#
# install recital shared library path in ldconfig
#
addldconfig()
{
  if [ "${linux}" = "1" ]; then
    if [ -f /etc/ld.so.conf ]; then
      path=`grep "${ROI_ROOT}" /etc/ld.so.conf`
      if [ "${path}" = "" ]
      then
        cat /etc/ld.so.conf > /tmp/$$
        echo "${ROI_ROOT}shared"  >> /tmp/$$
        mv /etc/ld.so.conf  /etc/ld.so.conf.bck
        mv /tmp/$$ /etc/ld.so.conf
      fi
    else
      echo "${ROI_ROOT}shared"  > /etc/ld.so.conf
    fi
    ldconfig
  fi
}
#
# remove recital shared library path in ldconfig
#
delldconfig()
{
  if [ "${linux}" = "1" ]; then
    if [ -f /etc/ld.so.conf ]; then
      grep -v "${ROI_ROOT}" /etc/ld.so.conf > /tmp/$$
      mv /etc/ld.so.conf  /etc/ld.so.conf.bck
      mv /tmp/$$ /etc/ld.so.conf
    fi
    ldconfig
  fi
}
#
# install recital shared library path in ldconfig
#
addpamd()
{
  if [ -f /etc/pam.d/recital ];then
    rm /etc/pam.d/recital
  fi
  if [ -d /etc/pam.d ];then
    if [ -f /lib/security/pam_unix2.so ];then
      if [ -f ./uas/recital.unix2.pam ];then
        cp ./uas/recital.unix2.pam /etc/pam.d/recital
      fi
    else
      if [ -f ./uas/recital.pam ];then
        cp ./uas/recital.pam /etc/pam.d/recital
      fi
    fi
  fi
}
#
# remove db_rsibase for /etc/services
#
delrsibase()
{
  port=`grep db_rsibase /etc/services`
  if [ "${port}" != "" ];then
    grep -v db_rsibase /etc/services > /tmp/$$
    mv /etc/services /etc/services.bck
    mv /tmp/$$ /etc/services
  fi
}
#
# remove files from specified list
#
remove ()
{
  for i in `cat $1`
  do
    shared=`echo $i | cut -c 1-7`
    if [ "$shared" = "/shared" ];then
      if [ "$2" = 1 ];then
        reply="y"
      else
        reply="n"
        $echonl_b "Do you wish to uninstall the shared file? $i (y/n) [${reply}] : $echonl_a"
        read reply
        if [ "$reply" = "" ];then
          reply="n"
        fi
      fi
      if [ "$reply" = "y" -o "$reply" = "Y" ];then
        if [ -d ${ROI_ROOT}$i ];then
          rmdir ${ROI_ROOT}$i 2> /dev/null
        else
          rm ${ROI_ROOT}$i 2> /dev/null
        fi
      fi
    else
      if [ -d ${ROI_ROOT}$i ];then
       rmdir ${ROI_ROOT}$i 2> /dev/null
      else
       rm ${ROI_ROOT}$i 2> /dev/null
      fi
    fi
  done
}
#
# Set system specific variables
#
setprofile ()
{
  fpelicense=0
  linux=0
  if [ -f /etc/lilo.conf ]; then
    linux=1
  fi
  if [ -f /etc/grub.conf ]; then
    linux=1
  fi
  if [ "`uname -s`" = "Linux" ]; then
    linux=1
  fi
  echo -n | grep n  > /dev/null
  if [ $? != 0 ];then
    echonl_b="echo -n"
    echonl_a=""
  else
    echonl_b="echo"
    echo "\c" | grep "\c"  > /dev/null
    if [ $? != 0 ];then
      echonl_a="\c"
    else
      echonl_a=""	
    fi
  fi

  if [ "${linux}" = "1" ]; then
    silent=1
  fi

  if [ "${linux}" = "1" ]; then
    packcom="gzip"
    packext="gz"
  else
    echo "1         1" > comp.tst
    rm comp.tst.Z 2> /dev/null
    comptst=`compress comp.tst` 2> /dev/null
    if [ "$comptst" = "" ];then
      packcom="compress"
      packext="Z"
    else
      packcom="pack"
      packext="z"
    fi
    rm comp.tst 2> /dev/null
    rm comp.tst.Z 2> /dev/null
  fi
  case $ROI_MACHINE
  in
  054)
    slext="a"
    ;;
  020)
    slext="sl"
    ;;
  061)
    slext="sl"
    ;;
  *)
    slext="so"
    ;;
  esac
}
addlicense()
{
  if [ "$1" = "" ];then
    echo "Usage: addlicense file"
    exit -1
  fi
   
  if [ -f $1 ];then
    paste=`cat $1`
  else
    paste=$1
  fi 

  if [ "$paste" = "" ];then
    echo "Invalid license string '$paste'"
    exit -1
  fi

  test=`echo $paste | cut -d "|" -f1`
  case ${test} 
  in
    RDS|RVD|RWD|RTD|RUS)
      counter=1
      ;;
    *)
      echo "Recital Error: product '$test' not found."
      exit -1
      ;;
  esac
  line=`echo $paste | cut -d "|" -f$counter`

  while [ "$counter" != "19" ]
  do
    counter=`expr ${counter} + 1`
    line=`echo $paste | cut -d "|" -f$counter`
    echo "$line" >> /tmp/$$
    if [ "$counter" = "2" ];then
       if [ "$line" != "$ROI_MACHINE" ];then
          echo "Invalid platform code '$line'"
          exit -1
       fi
    elif [ "$counter" = "4" ];then
       filename=${line}
    elif [ "$counter" = "7" ];then
       if [ "$filename" = "" ];then
          filename=${line}
       fi
    fi
  done
  product=`echo $filename | cut -c 1-1`
  if [ ! -d ${ROI_ROOT}/licenses ];then
    mkdir ${ROI_ROOT}/licenses
  fi
  case ${product} 
  in
    D)
      licdir=rds
      ;;
    W)
      licdir=rwd
      ;;
    S)
      licdir=rus
      ;;
    T)
      licdir=rtd
      ;;
    V)
      licdir=rvd
      ;;
    *)
      echo "Recital Error: Invlaid product code '$product'."
      exit -1
      ;;
  esac
  if [ ! -d ${ROI_ROOT}/licenses/${licdir} ];then
    mkdir ${ROI_ROOT}/licenses/${licdir}
  fi
  mv /tmp/$$ ${ROI_ROOT}/licenses/${licdir}/${filename}.db
  chmod +r ${ROI_ROOT}/licenses/${licdir}/${filename}.db
  case ${test} 
  in
    RTD|RUS)
      if [ -f /usr/bin/sudo -a ${USER} != "root" ];then
         SUDO="sudo"
      else
         SUDO=""
      fi
      if [ -f /usr/bin/dbusers ];then
        if [ -f ${ROI_ROOT}/terminaldeveloper/users.db ];then
          ${SUDO} dbusers -r  > /dev/null
	    else
          ${SUDO} dbusers -c  > /dev/null
	    fi
      fi
      ;;
  esac
}
#
# some functions can be called as $1 
if [ "$1" != "" ];then
  case $1
  in
    addlicense)
      for file in `ls /usr/bin/recital*.sh`
      do
         . $file
      done
      $1 $2 $3
    ;;
    uninstallproducts)
      for file in `ls /usr/bin/recital*.sh`
      do
         . $file
      done
      $1 $2
    ;;
  esac
fi
